==> clipspy-0.1.2.tar.gz: clipspy-0.1.2/clips/__init__.py <==
# Copyright (c) 2016-2017, Matteo Cafasso
# All rights reserved.

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:

# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.

# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.

# 3. Neither the name of the copyright holder nor the names of its contributors
# may be used to endorse or promote products derived from this software without
# specific prior written permission.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
# BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
# OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
# OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
# OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
# EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

__all__ = ('CLIPSError',
           'Environment',
           'Router',
           'LoggingRouter',
           'ImpliedFact',
           'TemplateFact',
           'Strategy',
           'SalienceEvaluation',
           'Verbosity',
           'ClassDefaultMode',
           'TemplateSlotDefaultType',
           'Symbol',
           'SaveMode')

from clips.error import CLIPSError
from clips.environment import Environment
from clips.common import Symbol, SaveMode
from clips.router import Router, LoggingRouter
from clips.facts import ImpliedFact, TemplateFact
from clips.common import Strategy, SalienceEvaluation, Verbosity
from clips.common import ClassDefaultMode, TemplateSlotDefaultType

# make data namespace visible to other modules
from clips import data

==> clipspy-0.3.1.tar.gz: clipspy-0.3.1/clips/__init__.py <==
# Copyright (c) 2016-2018, Matteo Cafasso
# All rights reserved.

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:

# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.

# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.

# 3. Neither the name of the copyright holder nor the names of its contributors
# may be used to endorse or promote products derived from this software without
# specific prior written permission.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
# BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
# OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
# OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
# OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
# EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

from clips.error import CLIPSError
from clips.environment import Environment
from clips.router import Router, LoggingRouter
from clips.facts import ImpliedFact, TemplateFact
from clips.common import Symbol, SaveMode, InstanceName
from clips.common import Strategy, SalienceEvaluation, Verbosity
from clips.common import ClassDefaultMode, TemplateSlotDefaultType

# make data namespace visible to other modules
from clips import data

__all__ = ('CLIPSError',
           'Environment',
           'Router',
           'LoggingRouter',
           'ImpliedFact',
           'TemplateFact',
           'Strategy',
           'SalienceEvaluation',
           'Verbosity',
           'ClassDefaultMode',
           'TemplateSlotDefaultType',
           'Symbol',
           'InstanceName',
           'SaveMode')
